Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(754)

Unified Diff: chrome/browser/resources/bookmark_manager/js/main.js

Issue 390983009: fix for Text is not displaying in search box after pressing the ctrl+z key in Bookmark Manager if d… (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Incorporated review comments Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « AUTHORS ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/resources/bookmark_manager/js/main.js
diff --git a/chrome/browser/resources/bookmark_manager/js/main.js b/chrome/browser/resources/bookmark_manager/js/main.js
index d01fca221906f05f8299c542c69c4ed94c507bab..de23c3a95e92266e45df74f8fd8a2827f8ea263a 100644
--- a/chrome/browser/resources/bookmark_manager/js/main.js
+++ b/chrome/browser/resources/bookmark_manager/js/main.js
@@ -459,9 +459,11 @@ function handleCanExecuteForDocument(e) {
!isUnmodifiable(tree.getBookmarkNodeById(list.parentId));
break;
case 'undo-command':
// The global undo command has no visible UI, so always enable it, and
// just make it a no-op if undo is not possible.
- e.canExecute = true;
+ e.canExecute = e.currentTarget.activeElement !== $('term');
break;
default:
canExecuteForList(e);
@@ -459,9 +459,11 @@ function handleCanExecuteForDocument(e) {
break;
case 'undo-command':
- // The global undo command has no visible UI, so always enable it, and
+ // If the search box is active, pass the undo command through
+ // (fixes http://crbug.com/278112). Otherwise, because
+ // the global undo command has no visible UI, always enable it, and
// just make it a no-op if undo is not possible.
« no previous file with comments | « AUTHORS ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698